==> hellosign-java-sdk-3.5.6-sources.jar: com/hellosign/sdk/resource/support/TemplateRole.java <==
package com.hellosign.sdk.resource.support;

/**
 * The MIT License (MIT)
 * 
 * Copyright (C) 2015 hellosign.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import org.json.JSONObject;

import com.hellosign.sdk.HelloSignException;
import com.hellosign.sdk.resource.AbstractResource;

/**
 * Resource class that represents a signer or CC role for a Template.
 * ("order" won't matter for the CC role, but we'll use this to 
 * represent it for now anyway).
 * 
 * @author "Chris Paul (chris@hellosign.com)"
 */
public class TemplateRole extends AbstractResource {

    public static final String SIGNER_ROLE_NAME = "name";
    public static final String SIGNER_ROLE_ORDER = "order";

    public TemplateRole(JSONObject json) throws HelloSignException {
        super(json, null);
    }

    public String getRole() {
        return getString(SIGNER_ROLE_NAME);
    }

    public Integer getOrder() {
        return getInteger(SIGNER_ROLE_ORDER);
    }
}

==> hellosign-java-sdk-4.0.11-sources.jar: com/hellosign/sdk/resource/support/TemplateRole.java <==
package com.hellosign.sdk.resource.support;

/**
 * The MIT License (MIT)
 * 
 * Copyright (C) 2015 hellosign.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import org.json.JSONObject;

import com.hellosign.sdk.HelloSignException;
import com.hellosign.sdk.resource.AbstractResource;

/**
 * Resource class that represents a signer or CC role for a Template. ("order"
 * won't matter for the CC role, but we'll use this to represent it for now
 * anyway).
 * 
 * @author "Chris Paul (chris@hellosign.com)"
 */
public class TemplateRole extends AbstractResource {

    public static final String SIGNER_ROLE_NAME = "name";
    public static final String SIGNER_ROLE_ORDER = "order";

    public TemplateRole(JSONObject json) throws HelloSignException {
        super(json, null);
    }

    public String getRole() {
        return getString(SIGNER_ROLE_NAME);
    }

    public Integer getOrder() {
        return getInteger(SIGNER_ROLE_ORDER);
    }
}
